<!-- Google +1 -->
<g:plusone size="medium"></g:plusone>
<script type="text/javascript">
    (function() {
        var po = document.createElement('script'); po.type = 'text/javascript'; po.async = true;
        po.src = 'https://apis.google.com/js/plusone.js';
        var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(po, s);
    })();
</script>
<div style="display: none">
    <img itemprop="image" src="{g1_image}">            
</div>

<!-- Tweeter -->
<a href="https://twitter.com/share" class="twitter-share-button">Tweet</a>
<script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0];if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src="//platform.twitter.com/widgets.js";fjs.parentNode.insertBefore(js,fjs);}}(document,"script","twitter-wjs");</script>

<!-- FaceBook -->
<div id="fb-root"></div>
<script>(function(d, s, id) {
    var js, fjs = d.getElementsByTagName(s)[0];
    if (d.getElementById(id)) return;
    js = d.createElement(s); js.id = id;
    js.src = "//connect.facebook.net/uk_UA/all.js#xfbml=1";
    fjs.parentNode.insertBefore(js, fjs);
}(document, 'script', 'facebook-jssdk'));</script>
<div class="fb-like" data-send="false" data-layout="button_count" data-width="120" data-show-faces="false"></div>

<!-- VK -->
<script type="text/javascript" src="https://vkontakte.ru/js/api/share.js?11" charset="windows-1251"></script>
<script type="text/javascript">
document.write(VK.Share.button({
    url: '{vk_url}',
    title: '{vk_title}',
    description: '{vk_description}',
    image: '{vk_image}',
    noparse: '{vk_noparse}'
},
{
    type: '{vk_type}', 
    text: '{vk_text}'}
));
</script>

<style type="text/css">
    .soc_buttons{
        border-collapse: collapse;
        border-spacing: 0;
        margin-bottom: 15px;
    }
    .soc_buttons td{
        text-align: center;
    }
    #___plusone_0{
        width: 80px !important;
        margin-left: 15px !important;
    }
    .fb-like{
        width: 80px !important;
        display: block !important;
    }
    #vkshare0{
        width: 50px !important;
    }
    .twitter-share-button {
        
    }
    .fb_iframe_widget span {
        vertical-align: inherit !important;
    }
    iframe[id^="oauth2relay"] {
        position: fixed !important;
    }
</style>