<div class="share-social">
    <table class="soc_buttons">
        <tr>
             <td style="padding-right:10px;">
            <!-- FaceBook -->
            <div id="fb-root"></div>
            <script>(function(d, s, id) {
                var js, fjs = d.getElementsByTagName(s)[0];
                if (d.getElementById(id)) return;
                js = d.createElement(s); js.id = id;
                js.src = "//connect.facebook.net/en_US/all.js#xfbml=1";
                fjs.parentNode.insertBefore(js, fjs);
            }(document, 'script', 'facebook-jssdk'));</script>
            <div class="fb-like" data-href="{url}" data-send="false" data-layout="button_count" data-width="120" data-show-faces="false"></div>
        </td>
        <td>
            <!-- VK -->
            <script type="text/javascript" src="https://vk.com/js/api/share.js?11" charset="windows-1251"></script>
            <script type="text/javascript">
            document.write(VK.Share.button({
                url: '{url}',
                title: '{title}',
                description: '{description}',
                image: '{vk_image}',
                noparse: '{vk_noparse}'
            },
            {
                type: '{vk_type}', 
                text: '{vk_text}'}
        ));
            </script>
        </td>
            <td>
                <!-- Google +1 -->
        <g:plusone size="medium" href="{url}"></g:plusone>
        <script type="text/javascript">
            (function() {
                var po = document.createElement('script'); po.type = 'text/javascript'; po.async = true;
                po.src = 'https://apis.google.com/js/plusone.js';
                var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(po, s);
            })();
        </script>
        <div style="display: none">
            <img itemprop="image" src="{g1_image}">            
        </div>
        </td>
        <td>
            <!-- Tweeter -->
            <a href="https://twitter.com/share" class="twitter-share-button" data-url="{url}">Tweet</a>
            <script>!function(d,s,id){var js,fjs=d.getElementsByTagName(s)[0];if(!d.getElementById(id)){js=d.createElement(s);js.id=id;js.src="//platform.twitter.com/widgets.js";fjs.parentNode.insertBefore(js,fjs);}}(document,"script","twitter-wjs");</script>    
        </td>
        </tr>
    </table>
</div>
<style type="text/css">
    .soc_buttons{
        border-collapse: collapse;
        border-spacing: 0;
        margin-bottom: 15px;
    }
    .soc_buttons td{
        text-align: center;
    }
    #___plusone_0{
        width: 80px !important;
        margin-left: 15px !important;
    }
    .fb-like{
        width: 80px !important;
        display: block !important;
    }
    #vkshare0{
        width: 50px !important;
    }
    .twitter-share-button {
        
    }
    .fb_iframe_widget span {
        vertical-align: inherit !important;
    }
    iframe[id^="oauth2relay"] {
        position: fixed !important;
    }
</style>